#
# spec file for package dtc
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define         sover 1
Name:           dtc
Version:        1.4.4
Release:        lp150.1.9
Summary:        Device-tree compiler
License:        GPL-2.0+
Group:          Development/Tools/Building
Url:            https://github.com/dgibson/dtc
Source0:        https://github.com/dgibson/dtc/archive/v%{version}.tar.gz#/dtc-%{version}.tar.gz
Source1:        baselibs.conf
Patch3:         dtc-license.patch
Patch4:         use-tx-as-the-type-specifier-instead-of-zx.patch
BuildRequires:  bison
BuildRequires:  flex

%description
PowerPC kernels are moving towards requiring a small Open
Firmware-style device tree as the only means of passing information
from bootloaders/firmware to the kernel. This does not require a full
Open Firmware implementation. DTC (Device Tree Compiler) is a tool to
create a static device tree, which is adequate for most embedded
systems (since their topology will not vary across reboots). DTC is
available via a git tree: git://ozlabs.org/srv/projects/dtc/dtc.git

%package -n libfdt%{sover}
Summary:        Device tree library
Group:          Development/Libraries/C and C++

%description -n libfdt%{sover}
libfdt is a library to process Open Firmware style device trees on various
architectures.

%package -n libfdt-devel
Summary:        Development headers for device tree library
Group:          Development/Libraries/C and C++
Requires:       libfdt%{sover} = %{version}-%{release}
# Provide previously used incorrectly named devel package
Provides:       libfdt1-devel = %{version}-%{release}
Obsoletes:      libfdt1-devel < %{version}-%{release}

%description -n libfdt-devel
This package provides development files for libfdt

%prep
%setup -q
%patch3
%patch4

%build
make %{?_smp_mflags} V=1

%install
%make_install PREFIX=%{_prefix} LIBDIR=%{_libdir}
install -p -m 644 libfdt/libfdt_env.h %{buildroot}/%{_includedir}
rm -f %{buildroot}/%{_libdir}/*.a

%check
make %{?_smp_mflags} check

%files
%defattr(-,root,root)
%doc README.license Documentation/manual.txt
%{_bindir}/convert-dtsv0
%{_bindir}/dtc
%{_bindir}/dtdiff
%{_bindir}/fdtdump
%{_bindir}/fdtget
%{_bindir}/fdtput

%post -n libfdt%{sover} -p /sbin/ldconfig
%postun -n libfdt%{sover} -p /sbin/ldconfig

%files -n libfdt%{sover}
%defattr(-,root,root,-)
%doc GPL
%{_libdir}/libfdt-%{version}.so
%{_libdir}/libfdt.so.*

%files -n libfdt-devel
%defattr(-,root,root,-)
%{_libdir}/libfdt.so
%{_includedir}/*

%changelog
* Sun Mar 12 2017 mpluskal@suse.com
- Update to version 1.4.4:
  * fdtput: Remove star from value_len documentation
  * fdtget: Use @return to document the return value
  * tests: Make realloc_fdt() really allocate *fdt
  * libfdt: overlay: Check the value of the right variable
  * dtc: Simplify asm_emit_string() implementation
  * libfdt: Change names of sparse helper macros
  * Fix assorted sparse warnings
  * Clean up gcc attributes
  * dtc: Don't abuse struct fdt_reserve_entry
- Refresh patches
- Make building more verbose
- Run tests
* Fri Mar  3 2017 jloeser@suse.com
- version update to 1.4.3
  * Add printf format attributes
  * Correct some broken printf() like format mismatches
  * libfdt: Add fdt_setprop_empty()
  * libfdt: Remove undefined behaviour setting empty properties
  * Print output filename as part of warning messages
  * dtc: Use streq() in preference to strcmp()
  * checks: Add Warning for stricter node name character checking
  * checks: Add Warning for stricter property name character checking
  * dtc: pos parameter to srcpos_string() can't be NULL
  * livetree.c: Fix memory leak
* Mon Feb  6 2017 jloeser@suse.com
- version update to 1.4.2
  * including patches up to git commit 3b9c9709
  * Fix NULL pointer use in dtlabel + dtref case
  * fdtdump: check fdt if not in scanning mode
  * Fix memory leak in character literal parsing
  * Don't always generate __symbols__ for plugins
  * Plugin and fixup support
  * fix fdt_stringlist_search()
  * fix fdt_stringlist_count()
  * improve tests
  * minor bugfixes/typos
  * including symbols in version.lds
  * no changelog available
- modified patches:
  * use-tx-as-the-type-specifier-instead-of-zx.patch
* Sat Dec 12 2015 mpluskal@suse.com
- Obsolete old devel package as well
* Sat Dec  5 2015 mpluskal@suse.com
- Cleanup spec file with spec-cleaner
- Dont include soname version in devel package name
* Mon Nov  9 2015 p.drouand@gmail.com
- Update to version 1.4.1
  * No changelog available
- Use download Url as source
- Use original project page as home page
* Fri Mar  7 2014 ro@suse.de
- add use-tx-as-the-type-specifier-instead-of-zx.patch
  taken from fedora to fix build on s390
* Tue Jul  9 2013 dmueller@suse.com
- update to 1.4.0 (bnc#826457):
- dtc-check.patch, dtc-flattree.patch: Remove
* Wed Jun 19 2013 dmueller@suse.com
- rename ftdump to dtc-ftdump to avoid conflict with ft2demos
* Tue Jun 18 2013 afaerber@suse.de
- Recent Git versions of dtc install libfdt_env.h, so that
  QEMU 1.6.0 will require this file. Install it for compatibility.
* Fri May 24 2013 afaerber@suse.de
- Use %%makeinstall in place of %%make_install, for SLE_11_SP2
* Sun Sep 18 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
- Implement baselibs config
* Fri Jul  1 2011 k0da@opensuse.org
- libfdt1 subpackage
  libfdt1-devel
- dtc 1.3.0 update
  dtc: Add code to make diffing trees easier
  dtc: Extend and better test dtbs_equal utility programs
  dtc: Audit and fix valgrind errors
  Assorted cleanups and extensions for ftdump
  Fix dtc bugs for 64-bit compile
- fix URL as mntioned site is no longer available
* Sat Feb  6 2010 jengelh@medozas.de
- disable failing `make check` on SPARC
* Thu Jan 24 2008 olh@suse.de
- update to 1.1.0 final
  clearify license issues, run testsuite
* Fri Aug 10 2007 olh@suse.de
- update to 1.0.0 final
  - first official release
* Mon Jun 18 2007 olh@suse.de
- update to current state
    dtc: Fix recognition of whitespace characters
    Implement the -R option and add a -S option.
    Add -o <output file> to the usage message.
    Fix reserve map output for asm format.
    Assemble the blob in memory before writing it out.
    Fix the -S to modify the totalsize properly.
    dtc: parse NOP in dtb input
* Thu Mar 29 2007 olh@suse.de
- add flex and bison to buildrequires
  fix endian bug in ftdump, add C style includes
* Fri Mar 23 2007 olh@suse.de
- initial package to build PS3 kernel
